<?php

namespace App\Filament\Resources\InvoiceReportResource\RelationManagers;

use App\Filament\Resources\InvoiceResource;
use Filament\Forms;
use Filament\Forms\Form;
use Filament\Resources\RelationManagers\RelationManager;
use Filament\Support\Enums\FontWeight;
use Filament\Tables\Columns\TextColumn;
use Filament\Tables\Table;

class InvoicesRelationManager extends RelationManager
{
    protected static string $relationship = 'invoices';

    public function form(Form $form): Form
    {
        return $form
            ->schema([
                Forms\Components\TextInput::make('id')
                    ->required()
                    ->maxLength(255),
            ]);
    }

    public function table(Table $table): Table
    {
        return $table
            ->recordTitleAttribute('internal_id')
            ->recordUrl(fn ($record) => InvoiceResource::getUrl('edit', ['record' => $record->id]))
            ->columns([
                TextColumn::make('internal_id')
                    ->label('ID')
                    ->extraHeaderAttributes(['class' => 'w-full'])
                    ->color('primary'),
                TextColumn::make('date')
                    ->label('Created')
                    ->date(),
                TextColumn::make('subtotal')
                    ->alignRight()
                    ->money(),
                TextColumn::make('gst_amount')
                    ->alignRight()
                    ->money(),
                TextColumn::make('pst_amount')
                    ->alignRight()
                    ->formatStateUsing(function ($state) {
                        return $state == 0.00 ? '-' : '$'.$state;
                    }),
                TextColumn::make('total')
                    ->alignRight()
                    ->money()
                    ->weight(FontWeight::Bold),
                TextColumn::make('status'),
            ])
            ->filters([
                //
            ])
            ->headerActions([
            ])
            ->actions([
            ])
            ->bulkActions([
            ]);
    }
}
